@@ -17,7 +17,9 @@ repr_list_generic <- function(
 	escape_fun = identity) {
 	
 	nms <- names(vec)
-	if (!is.null(nms)) {
+	if (identical(nms, '')) {
+		nms <- NULL
+	} else if (!is.null(nms)) {
 		nms <- as.character(sapply(nms, as_name_or_na, USE.NAMES = FALSE))  # adds `` around special chars
 		nms <- escape_fun(nms)
 	}
